# xymap
### Ongoing project
This is Alpha version

Bivariate colormap solutions.

Inspired by [xycmap](https://github.com/rbjansen/xycmap).

#### Installation
`pip install xymap`

#### todo list:
1. provide color ramps options
2. add band palette to tif
3. add user defined color ramps
4. interpolate color ramps
5. vector format support
6. triangle mesh support `Done`

